==> inkribbon-6.x-6.3.tar.gz: inkribbon/inkribbon/templates/maintenance-page.tpl.php <==
<?php
// $Id: maintenance-page.tpl.php,v 1.1.2.7 2010/08/30 12:11:01 mverbaar Exp $
?>
<!DOCTYPE html>
<html lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
<head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <?php print $styles; ?>
  <?php print $scripts; ?>
</head>
<body class="<?php print $body_classes; ?>">

  <div id="page">

    <div id="header">

      <?php if ($logo): ?>
        <div id="logo">
          <a href="<?php print url('<front>'); ?>" rel="home"><?php print $logo; ?></a>
        </div>
      <?php endif; ?>

      <?php if ($site_name): ?>
        <<?php print $site_name_wrapper; ?> id="site-name">
          <a href="<?php print url('<front>'); ?>" rel="home"><?php print $site_name; ?></a>
        </<?php print $site_name_wrapper; ?>>
      <?php endif; ?>

      <?php if ($site_slogan): ?>
        <div id="site-slogan"><?php print $site_slogan; ?></div>
      <?php endif; ?>

      <?php if ($header): ?>
        <div id="header-region">
          <?php print $header; ?>
        </div>
      <?php endif; ?>

    </div> <!-- /#header -->

    <div id="main">

      <?php if ($messages): ?>
        <div id="console"><?php print $messages; ?></div>
      <?php endif; ?>

      <div id="content">
        <?php if ($highlight): ?>
          <div id="highlight">
            <?php print $highlight; ?>
          </div>
        <?php endif; ?>

        <?php print $breadcrumb; ?>

        <?php if ($title): ?>
          <h1 id="page-title"><?php print $title; ?></h1>
        <?php endif; ?>

        <?php print $tabs; ?>
        <?php print $help; ?>

        <div id="content-region"><?php print $content; ?></div>
      </div> <!-- /#content -->

      <?php if ($sidebar): ?>
        <div id="sidebar">
          <?php print $sidebar; ?>
        </div>
      <?php endif; ?>

      <?php if ($sidebar_second): ?>
        <div id="sidebar-second">
          <?php print $sidebar_second; ?>
        </div>
      <?php endif; ?>

    </div> <!-- /#main -->

    <?php if ($footer): ?>
      <div id="footer">
        <?php print $footer; ?>
      </div>
    <?php endif; ?>

  </div> <!-- /#page -->

  <?php print $closure; ?>

</body>
</html>

==> inkribbon-6.x-6.4.tar.gz: inkribbon/inkribbon/templates/maintenance-page.tpl.php <==
<?php
// $Id: maintenance-page.tpl.php,v 1.1.2.8 2010/08/31 09:04:52 mverbaar Exp $
?>
<!DOCTYPE html>
<html lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
<head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <?php print $styles; ?>
  <?php print $scripts; ?>
</head>
<body class="<?php print $body_classes; ?>">

  <div id="page">

    <div id="header">

      <?php if ($logo): ?>
        <div id="logo">
          <a href="<?php print url('<front>'); ?>" rel="home"><?php print $logo; ?></a>
        </div>
      <?php endif; ?>

      <?php if ($site_name): ?>
        <<?php print $site_name_wrapper; ?> id="site-name">
          <a href="<?php print url('<front>'); ?>" rel="home"><?php print $site_name; ?></a>
        </<?php print $site_name_wrapper; ?>>
      <?php endif; ?>

      <?php if ($site_slogan): ?>
        <div id="site-slogan"><?php print $site_slogan; ?></div>
      <?php endif; ?>

      <?php if ($header): ?>
        <div id="header-region">
          <?php print $header; ?>
        </div>
      <?php endif; ?>

    </div> <!-- /#header -->

    <div id="main">

      <?php if ($messages): ?>
        <div id="console"><?php print $messages; ?></div>
      <?php endif; ?>

      <div id="content">
        <?php if ($highlighted): ?>
          <div id="highlighted">
            <?php print $highlighted; ?>
          </div>
        <?php endif; ?>

        <?php print $breadcrumb; ?>

        <?php if ($title): ?>
          <h1 id="page-title"><?php print $title; ?></h1>
        <?php endif; ?>

        <?php print $tabs; ?>
        <?php print $help; ?>

        <div id="content-region"><?php print $content; ?></div>
      </div> <!-- /#content -->

      <?php if ($sidebar): ?>
        <div id="sidebar">
          <?php print $sidebar; ?>
        </div>
      <?php endif; ?>

      <?php if ($sidebar_second): ?>
        <div id="sidebar-second">
          <?php print $sidebar_second; ?>
        </div>
      <?php endif; ?>

    </div> <!-- /#main -->

    <?php if ($footer): ?>
      <div id="footer">
        <?php print $footer; ?>
      </div>
    <?php endif; ?>

  </div> <!-- /#page -->

  <?php print $closure; ?>

</body>
</html>
